@@ -322,10 +322,8 @@ Ext.ux.tree.TreeHeaderFilters = Ext.extend(Ext.util.Observable, {
 								fc.on('change',function(field)
 									{
 										var t = field.getXType();
-										if((t=='combo' || t=='datefield' || t=='m3-select') && this.checkHasValue(field)) {
-											//Предотвращает двойное обновление грида, проверка на наличие значения
-											//дает возможность обновить грид если значение в фильтре отсутствует.
-											return;
+										if(t=='combo' || t=='datefield'){ //avoid refresh twice for combo select 
+										return;
 										}else{
 											this.applyFilter(field);
 										}
@@ -440,10 +438,6 @@ Ext.ux.tree.TreeHeaderFilters = Ext.extend(Ext.util.Observable, {
 			}
 		}
 	},
-	checkHasValue: function(field){
-		var value = this.getFieldValue(field)
-		return !(value === null || value === "" || value === undefined);
-	},
     getHeaderCell: function(columnId){
     	var cols = this.tree.columns,
             colCount = cols.length,
@@ -505,26 +499,13 @@ Ext.ux.tree.TreeHeaderFilters = Ext.extend(Ext.util.Observable, {
 		
 		return fc;
 	},
-
-	setIsNotRendered: function(el){
-        if(el.items){
-            for(var subEl in el.items){
-			    this.setIsNotRendered(el.items[subEl]);
-		    }
-        }else if(el.rendered){
-            el.rendered = false;
-        }
-    },
-
+	
 	renderFilters: function()
 	{
 		if(!this.fcc)
 			return;
 		for(var cid in this.fcc)
 		{
-			if(Ext.isIE){
-                this.setIsNotRendered(this.fcc[cid]);
-            }
 			this.renderFilterContainer(cid, this.fcc[cid]);
 		}
 		this.setFilters(this.filters);
@@ -636,14 +617,7 @@ Ext.ux.tree.TreeHeaderFilters = Ext.extend(Ext.util.Observable, {
 		{
 			vals[name] = this.filters[name];
 		}
-		if (status === null){
-			// если переменная status не определенна, то нет возможности установить атрибут
-			// падает ошибка
-			status = new Object;
-			status["gridHeaderFilters"] = vals;
-		}else{
-			status["gridHeaderFilters"] = vals;
-		}
+		status["gridHeaderFilters"] = vals;
 		return true;
 	},
    
@@ -803,12 +777,13 @@ Ext.ux.tree.TreeHeaderFilters = Ext.extend(Ext.util.Observable, {
 		for(var fn in this.filterFields)
 		{
 			// только для Ext.m3.ObjectTree
-			if (this.tree.actionContextJson) {
-				delete this.tree.actionContextJson[fn];
+			if (this.getContext()) {
+				delete this.getContext()[fn];
 			}
 		}
 		// проставим заново
 		// только для Ext.m3.ObjectTree
+        // TODO: Протестировать контекст
 		this.tree.actionContextJson = Ext.applyIf(this.tree.actionContextJson || {}, this.filters);
 		this.tree.refreshStore();
 		//this.tree.getLoader().baseParams = Ext.applyIf(this.tree.getLoader().baseParams, this.filters);
